@@ -113,7 +113,7 @@ static void start_sequencer(JammoMentor* mentor, const gchar* speech, gboolean i
 
 static void say_start_after_prelude(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer sequencer){
 	if (interrupted){
-		singinggame_start_sequencer(JAMMO_SEQUENCER(sequencer));
+		start_sequencer(NULL, NULL, interrupted, sequencer);
 		return;
 	}
 
@@ -123,7 +123,7 @@ static void say_start_after_prelude(JammoMentor* mentor, const gchar*speech, gbo
 
 static void say_name_of_song(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer sequencer){
 	if (interrupted){
-		singinggame_start_sequencer(JAMMO_SEQUENCER(sequencer));
+		start_sequencer(NULL, NULL, interrupted, sequencer);
 		return;
 	}
 
@@ -144,7 +144,7 @@ static void song_view_showed(ClutterTimeline* t, gpointer sequencer){
 }
 
 static void start_sequencer_after_animation(ClutterTimeline* t, gpointer sequencer){
-	singinggame_start_sequencer(JAMMO_SEQUENCER(sequencer));
+	start_sequencer(NULL, NULL, FALSE, sequencer);
 }
 
 
@@ -461,7 +461,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		}
 
 	ClutterColor red = { 255, 0, 0, 128 };
-	singinggame_add_cursor(&red, sequencer, view);
+	singinggame_add_cursor(&red, sequencer, view, FALSE);
 
 	return FALSE;
 }
