@@ -47,7 +47,7 @@ static void load_state_from_file(FILE *ifp) {
 			not_ready=FALSE;
 			continue;
 		}
-		ClutterActor* track_view; //Will be jammo_trac_view or jammo_miditrack_view
+		ClutterActor* track_view = NULL; //Will be jammo_trac_view or jammo_miditrack_view
 
 		if(strncmp(my_string, "Track-type:", 11) == 0) {
 			printf("New track.\n");
