@@ -274,16 +274,6 @@ ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type, guint64
 	return track_view_actor;
 }
 
-/*
-static void sequencer_sequencer_track_view_remove_last() {
-	if(tracks_in_use > 0) {
-		tracks_in_use--;
-		clutter_actor_destroy(track_views[tracks_in_use]->sequencer_track_view_container);
-		track_views[tracks_in_use] = NULL;
-	}
-}
-*/
-
 static ClutterAnimation * animate_buttonpress_release(ClutterActor *actor) {
 	ClutterAnimation *anim = clutter_actor_animate (actor,          /* the actor to animate */
 			CLUTTER_LINEAR, /* the easing mode */
@@ -307,28 +297,6 @@ static ClutterAnimation * animate_buttonpress_down(ClutterActor *actor) {
 }
 
 
-
-void create_dummy_note_file(gchar* filename)
-{
-	printf("Creating dummy note file %s\n", filename);
-	FILE *ofp;
-
-	if(!filename)
-		return;
-
-	ofp = fopen(filename, "w");
-	g_return_if_fail(ofp != NULL);
-
-	printf("Starting note insertion\n");
-	fprintf(ofp, "#use '#' for commenting out\n");
-	fprintf(ofp, "e4+ 2181683703\n");
-	fprintf(ofp, "a4+ 5181683703\n");
-	fprintf(ofp, "a4- 6181683703\n");
-
-	fclose(ofp);
-}
-
-
 /*
  * Event for pressing label on track, data points to track structure
  */
@@ -414,18 +382,6 @@ static void set_volume_slider_position_by_state(gint state) {
 
 }
 
-static int get_actor_height(ClutterActor *actor) {
-
-	gfloat width = 0;
-	gfloat height = 0;
-
-	clutter_actor_get_size (actor, &width, &height);
-
-	int retval = (gint)height;
-	return retval;
-
-}
-
 static void get_volume_background_coords(gfloat *position_x, gfloat *position_y) {
 
 	gfloat position_x_volume_background = clutter_actor_get_x(track_views[BUTTON_SEQUENCER_VOLUME_ACTIVE]->volume_button);
@@ -515,10 +471,10 @@ static void move_volume_slider(ClutterEvent *event) {
 	gint new_x, new_y;
 
 	new_x=position_x_volume_background + 2 ;
-	new_y=(gint)y_mouse_f - get_actor_height(BUTTON_VOLUME_SLIDER) / 2;;
+	new_y=(gint)y_mouse_f - clutter_actor_get_height(BUTTON_VOLUME_SLIDER) / 2;;
 
 	//Check top and bottom edges
-	gint slide_width = get_actor_height(TEXTURE_VOLUME_BACKGROUND) - get_actor_height(BUTTON_VOLUME_SLIDER);
+	gint slide_width = clutter_actor_get_height(TEXTURE_VOLUME_BACKGROUND) - clutter_actor_get_height(BUTTON_VOLUME_SLIDER);
 
 	gint top_edge = position_y_volume_background;
 	gint bottom_edge = position_y_volume_background + slide_width;
@@ -638,7 +594,7 @@ void fullsequencer_record_clicked (TangleButton* tanglebutton, gpointer none){
 }
 
 
-//TODO. add metronome-track
+//TODO. use metronome-track
 //is METRONOME_STATE used?
 void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
 	printf("fullsequencer: Metronome pressed\n");
