@@ -38,19 +38,19 @@ int * gp_jamming_state;
 JammoCollaborationJamming * g_collaboration_jamming;
 
 // function prototypes
-int slavesynchronize(gpointer data);
-int mastersynchronize(gpointer data);
-ClutterActor * make_instrument_grid (int type);
-void add_event_to_buffer(JammoCollaborationJamming* collaboration_jamming, char type,
+static int slavesynchronize(gpointer data);
+static int mastersynchronize(gpointer data);
+static ClutterActor * make_instrument_grid (int type);
+static void add_event_to_buffer(JammoCollaborationJamming* collaboration_jamming, char type,
 		char note, guint64 timestamp);
-void press (ClutterActor * actor, ClutterEvent * event, gpointer data);
-void release (ClutterActor * actor, ClutterEvent * event, gpointer data);
-int send_midi(gpointer data);
-int receive_midi(gpointer data);
+static void press (ClutterActor * actor, ClutterEvent * event, gpointer data);
+static void release (ClutterActor * actor, ClutterEvent * event, gpointer data);
+static int send_midi(gpointer data);
+static int receive_midi(gpointer data);
 void jammo_collaboration_jamming_on_sequencer_stopped_recording(JammoSequencer* sequencer, gpointer data);
 int store_jamming_data(JammoCollaborationJamming* collaboration_jamming);
 void exit_jamming(JammoCollaborationJamming * collaboration_jamming);
-void clean_up(JammoCollaborationJamming * collaboration_jamming);
+static void clean_up(JammoCollaborationJamming * collaboration_jamming);
 
 enum {
 	PROP_0/*,
@@ -265,7 +265,7 @@ void jammo_collaboration_jamming_set_peer_midi_location(JammoCollaborationJammin
 
 // signal handler for SIGPIPE
 // if the other end does not close connection properly we do not want to crash
-void signalhandler( int signal ) {
+static void signalhandler( int signal ) {
   *gp_jamming_state=JAMMINGSTATE_ERROR;
 }
 
@@ -283,7 +283,7 @@ static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer
 
 // synchronization function for slave
 // sends init, replies to rtt messages, counts the time specified by master
-int slavesynchronize(gpointer data) {
+static int slavesynchronize(gpointer data) {
 	char buffer[JAMMING_EVENTLEN+1];
 	struct timeval tv_select, tv_clock, tv_countstart;
 	struct timezone tz;
@@ -435,7 +435,7 @@ int slavesynchronize(gpointer data) {
 	return 0;
 }
 
-int mastersynchronize(gpointer data) {
+static int mastersynchronize(gpointer data) {
 	char buffer[JAMMING_EVENTLEN+1];
 	struct timeval tv_select, tv_recvd, tv_countstart, tv_sent, tv_clock;
 	struct timezone tz;
@@ -676,7 +676,7 @@ int mastersynchronize(gpointer data) {
 }
 
 // as simple as possible ui
-ClutterActor * make_instrument_grid (int type) {
+static ClutterActor * make_instrument_grid (int type) {
 
   ClutterColor transparency = { 255, 255, 255, 0 };
 	ClutterColor finish= { 100, 100, 100, 255 };
@@ -714,7 +714,7 @@ ClutterActor * make_instrument_grid (int type) {
 
 // a buffer is used to store multiple events that happen in a very short period of time
 // events are sent as a constant stream of single events so in some cases (e.g. chords) buffering is needed
-void add_event_to_buffer(JammoCollaborationJamming * collaboration_jamming, char type, char note, guint64 timestamp) {
+static void add_event_to_buffer(JammoCollaborationJamming * collaboration_jamming, char type, char note, guint64 timestamp) {
 	static int i;
 	if ( (collaboration_jamming->priv->currentevent) - (collaboration_jamming->priv->latestevent)==1 || (collaboration_jamming->priv->currentevent)-(collaboration_jamming->priv->latestevent)==-JAMMING_EVENTBUFFERSIZE) {
 		printf("event does not fit to buffer, oldest event from buffer was overwritten\n");
@@ -743,7 +743,7 @@ void add_event_to_buffer(JammoCollaborationJamming * collaboration_jamming, char
 
 // press callback for ui, note on is passed forward
 // it is possible to get a stuck local and remote note by not releasing in the same box as pressed
-void press (ClutterActor * actor, ClutterEvent * event, gpointer data) {
+static void press (ClutterActor * actor, ClutterEvent * event, gpointer data) {
   int octave = GPOINTER_TO_INT (data) / 100;
   int note = GPOINTER_TO_INT (data) - 100 * octave;
   char midinote = note+octave*12;
@@ -768,7 +768,7 @@ void press (ClutterActor * actor, ClutterEvent * event, gpointer data) {
 
 // release callback for ui, note off is passed forward
 // it is possible to get a stuck local and remote note by not releasing in the same box as pressed
-void release (ClutterActor * actor, ClutterEvent * event, gpointer data) {
+static void release (ClutterActor * actor, ClutterEvent * event, gpointer data) {
   int octave = GPOINTER_TO_INT (data) / 100;
   int note = GPOINTER_TO_INT (data) - 100 * octave;
   char midinote = note+octave*12;
@@ -784,7 +784,7 @@ void release (ClutterActor * actor, ClutterEvent * event, gpointer data) {
 }
 
 // this function is called when sending or receiving fails
-void handle_communication_error(JammoCollaborationJamming * collaboration_jamming) {
+static void handle_communication_error(JammoCollaborationJamming * collaboration_jamming) {
 	// when state is JAMMINGSTATE_ERROR midi is not sent or received anymore
 	collaboration_jamming->priv->jamming_state=JAMMINGSTATE_ERROR;
 	// if jamming should continue alone sequencer should not be stopped
@@ -794,7 +794,7 @@ void handle_communication_error(JammoCollaborationJamming * collaboration_jammin
 }
 
 // callback function for sending midi events to peer
-int send_midi(gpointer data) {
+static int send_midi(gpointer data) {
 	static guint64 clock;
 	static char buffer[JAMMING_EVENTLEN+1];
 	static int skipped, if_send;
@@ -873,7 +873,7 @@ int send_midi(gpointer data) {
 }
 
 // callback function for receiving midi events from peer
-int receive_midi(gpointer data) {
+static int receive_midi(gpointer data) {
 	static char buffer[JAMMING_EVENTLEN+1];
 	static struct timeval tv_select;
 	static fd_set rfds;
@@ -1300,7 +1300,7 @@ int jammo_collaboration_jamming_start(JammoCollaborationJamming * collaboration_
 }
 
 // unrefs sequencer and tracks which should cause deletion of those objects
-void clean_up(JammoCollaborationJamming * collaboration_jamming) {
+static void clean_up(JammoCollaborationJamming * collaboration_jamming) {
 	JammoSequencer * sequencer;
 	g_object_get(collaboration_jamming,"sequencer",&sequencer, NULL);
 
