@@ -70,10 +70,10 @@ GST_ELEMENT_DETAILS ("JamMo Slider",
 #define NUMBER_OF_INSTRUMENTS	     sizeof(instruments)/sizeof(*instruments)
 
 //This are for tuning slider
-#define DEFAULT_ATTACK 5000
-#define DEFAULT_DECAY 5000
+#define DEFAULT_ATTACK 0.2
+#define DEFAULT_DECAY 0.2
 #define DEFAULT_SUSTAIN 0.5
-#define DEFAULT_RELEASE 5000
+#define DEFAULT_RELEASE 0.2
 
 enum
 {
@@ -252,19 +252,19 @@ static void gst_jammo_slider_class_init (GstJammoSliderClass * klass)
           "Clear event list", FALSE,
           G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
  g_object_class_install_property (gobject_class, PROP_ATTACK,
-      g_param_spec_int ("attack", "attack",
-          "attack",
-          0, 100000, DEFAULT_ATTACK,
+      g_param_spec_float ("attack", "attack",
+          "Attack in seconds",
+          0.0, 20.0, DEFAULT_ATTACK,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  g_object_class_install_property (gobject_class, PROP_DECAY,
-      g_param_spec_int ("decay", "decay",
-          "decay",
-          0, 100000, DEFAULT_DECAY,
+      g_param_spec_float ("decay", "decay",
+          "Decay in seconds",
+          0.0, 20.0, DEFAULT_DECAY,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  g_object_class_install_property (gobject_class, PROP_RELEASE,
-      g_param_spec_int ("release", "release",
-          "release",
-          0, 100000, DEFAULT_RELEASE,
+      g_param_spec_float ("release", "release",
+          "Release in seconds",
+          0.0, 20.0, DEFAULT_RELEASE,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  g_object_class_install_property (gobject_class, PROP_SUSTAIN,
       g_param_spec_float ("sustain", "sustain", "sustain",
@@ -738,23 +738,23 @@ static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * sam
 		if (src->state==TRUE) {\
 	    if (!src->released) {\
 	      /* Attack */\
-				if (src->adsr_counter<src->attack) { \
-					value*=src->adsr_counter/((gfloat)src->attack);\
-					src->release_multiplier=src->adsr_counter/((gfloat)src->attack);\
+				if (src->adsr_counter< src->attack * src->samplerate) { \
+					value*=src->adsr_counter/(src->attack * src->samplerate);\
+					src->release_multiplier=src->adsr_counter/(src->attack * src->samplerate);\
 					src->adsr_counter++;\
 					/*printf("attack\n");*/\
 				}\
   \
 	      /* Decay */ \
-				if (src->adsr_counter >= src->attack && src->adsr_counter < src->attack+src->decay) {\
-					value*=(1-src->sustain)*(1-(src->adsr_counter/((gfloat)(src->attack+src->decay))))+src->sustain;\
-					src->release_multiplier=(1-src->sustain)*(1-(src->adsr_counter/((gfloat)(src->attack+src->decay))))+src->sustain;\
+				if (src->adsr_counter >= src->attack * src->samplerate && src->adsr_counter < (src->attack*src->samplerate)+(src->decay*src->samplerate)) {\
+					value*=(1-src->sustain)*(1-(src->adsr_counter/((src->attack*src->samplerate)+(src->decay*src->samplerate))))+src->sustain;\
+					src->release_multiplier=(1-src->sustain)*(1-(src->adsr_counter/((src->attack*src->samplerate)+(src->decay*src->samplerate))))+src->sustain;\
 					src->adsr_counter++; \
 					/*printf("decay\n");*/ \
 	      } \
   \
 				/* Sustain */ \
-				if (src->adsr_counter >= src->attack + src->decay) {\
+				if (src->adsr_counter >= (src->attack*src->samplerate)+(src->decay*src->samplerate)) {\
 					value*=src->sustain; \
 					src->release_multiplier=src->sustain;\
 					src->adsr_counter+=1; \
@@ -764,9 +764,9 @@ static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * sam
 \
 			/* Release */ \
 			if (src->released) {\
-				value*=src->release_multiplier*(1-(src->release_counter/((gfloat)src->release)));\
+				value*=src->release_multiplier*(1-(src->release_counter/(src->release*src->samplerate)));\
 				src->release_counter++;\
-				if (src->release_counter >= src->release) \
+				if (src->release_counter >= (src->release*src->samplerate)) \
 					src->state=FALSE;\
 				/*printf("release\n");*/ \
 			} \
@@ -1034,13 +1034,13 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
       src->instrument = g_value_get_int (value);
       break;
     case PROP_ATTACK:
-      src->attack = g_value_get_int (value);
+      src->attack = g_value_get_float (value);
       break;
     case PROP_DECAY:
-      src->decay = g_value_get_int (value);
+      src->decay = g_value_get_float (value);
       break;
     case PROP_RELEASE:
-      src->release = g_value_get_int (value);
+      src->release = g_value_get_float (value);
       break;
     case PROP_SUSTAIN:
       src->sustain = g_value_get_float (value);
@@ -1189,13 +1189,13 @@ static void gst_jammo_slider_get_property (GObject * object, guint prop_id,
       g_value_set_enum (value, src->instrument);
       break;
     case PROP_ATTACK:
-      g_value_set_int (value, src->attack);
+      g_value_set_float (value, src->attack);
       break;
     case PROP_DECAY:
-      g_value_set_int (value, src->decay);
+      g_value_set_float (value, src->decay);
       break;
     case PROP_RELEASE:
-      g_value_set_int (value, src->release);
+      g_value_set_float (value, src->release);
       break;
     case PROP_SUSTAIN:
        g_value_set_float (value, src->sustain);
